==> tengits_widgets-0.0.4.tar.gz: lib/selection/widget/t_selection_range_input_item_widget.dart <==
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:tengits_widgets/selection/selection_common_entity.dart';
import 'package:tengits_widgets/selection/t_event_bus.dart';
import 'package:tengits_widgets/selection/t_selection_config.dart';

typedef RangeChangedCallback = void Function(String minInput, String maxInput);

/// 清空自定义范围输入框焦点的事件类
class ClearSelectionFocusEvent {}

class TSelectionRangeItemWidget extends StatefulWidget {
  final TSelectionEntity item;

  final RangeChangedCallback? onRangeChanged;
  final ValueChanged<bool>? onFocusChanged;

  final bool isShouldClearText;

  final TextEditingController minTextEditingController;
  final TextEditingController maxTextEditingController;

  final TSelectionConfig themeData;

  const TSelectionRangeItemWidget({
    Key? key,
    required this.item,
    required this.minTextEditingController,
    required this.maxTextEditingController,
    this.isShouldClearText = false,
    this.onRangeChanged,
    this.onFocusChanged,
    required this.themeData,
  }) : super(key: key);

  @override
  _TSelectionRangeItemWidgetState createState() =>
      _TSelectionRangeItemWidgetState();
}

class _TSelectionRangeItemWidgetState
    extends State<TSelectionRangeItemWidget> {
  final FocusNode _minFocusNode = FocusNode();
  final FocusNode _maxFocusNode = FocusNode();

  @override
  void initState() {
    widget.minTextEditingController.text =
        (widget.item.customMap != null && widget.item.customMap!['min'] != null)
            ? widget.item.customMap!['min']?.toString() ?? ''
            : '';
    widget.maxTextEditingController.text =
        (widget.item.customMap != null && widget.item.customMap!['max'] != null)
            ? widget.item.customMap!['max']?.toString() ?? ''
            : '';

    //输入框焦点
    _minFocusNode.addListener(() {
      if (widget.onFocusChanged != null) {
        widget
            .onFocusChanged!(_minFocusNode.hasFocus || _maxFocusNode.hasFocus);
      }
    });

    _maxFocusNode.addListener(() {
      if (widget.onFocusChanged != null) {
        widget
            .onFocusChanged!(_minFocusNode.hasFocus || _maxFocusNode.hasFocus);
      }
    });

    widget.minTextEditingController.addListener(() {
      String minInput = widget.minTextEditingController.text;

      widget.item.customMap ??= {};
      widget.item.customMap!['min'] = minInput;
      widget.item.isSelected = true;
    });

    widget.maxTextEditingController.addListener(() {
      String maxInput = widget.maxTextEditingController.text;
      widget.item.customMap ??= {};
      widget.item.customMap!['max'] = maxInput;
      widget.item.isSelected = true;
    });

    TEventBus.instance
        .on<ClearSelectionFocusEvent>()
        .listen((ClearSelectionFocusEvent event) {
      _minFocusNode.unfocus();
      _maxFocusNode.unfocus();
    });

    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Padding(
      padding: const EdgeInsets.only(left: 20, right: 20, bottom: 20),
      child: Column(
        children: <Widget>[
          Container(
            margin: const EdgeInsets.only(bottom: 5),
            alignment: Alignment.centerLeft,
            child: Text(
              (widget.item.title.isNotEmpty ? widget.item.title : '自定义区间') +
                  "(" +
                  (widget.item.extMap['unit']?.toString() ?? '') +
                  ")",
              textAlign: TextAlign.left,
              style: const TextStyle(color:  Color(0xFF222222), fontSize: 16.0, fontWeight: FontWeight.w600),
            ),
          ),
          Row(
            children: <Widget>[
              getRangeTextField(false),
              const Text(
                '至',
                style: TextStyle(color:  Color(0xFF222222), fontSize: 14.0),
              ),
              getRangeTextField(true),
            ],
          )
        ],
      ),
    );
  }

  Widget getRangeTextField(bool isMax) {
    return Expanded(
      child: TextFormField(
        style: const TextStyle(color:  Color(0xFF222222), fontSize: 14.0),
        inputFormatters: [FilteringTextInputFormatter.digitsOnly],
        keyboardType: const TextInputType.numberWithOptions(),
        onChanged: (input) {
          widget.item.isSelected = true;
        },
        focusNode: isMax ? _maxFocusNode : _minFocusNode,
        controller: isMax
            ? widget.maxTextEditingController
            : widget.minTextEditingController,
        cursorColor: const Color(0xFF3072F6),
        textAlign: TextAlign.center,
        decoration: InputDecoration(
          hintStyle: const TextStyle(color:  Color(0xFFCCCCCC), fontSize: 14.0),
          hintText: (isMax ? '最大值' : '最小值'),
          enabledBorder: const UnderlineInputBorder(
              borderSide: BorderSide(
            width: 1,
            color: Color(0xFFF0F0F0),
          )),
          focusedBorder: const UnderlineInputBorder(
              borderSide: BorderSide(
            width: 1,
            color: Color(0xFFF0F0F0),
          )),
          contentPadding: const EdgeInsets.all(0),
        ),
      ),
    );
  }
}

==> tengits_widgets-0.0.10.tar.gz: lib/selection/widget/t_selection_range_input_item_widget.dart <==
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:tengits_widgets/selection/selection_common_entity.dart';
import 'package:tengits_widgets/selection/t_event_bus.dart';
import 'package:tengits_widgets/selection/t_selection_config.dart';

typedef RangeChangedCallback = void Function(String minInput, String maxInput);

/// 清空自定义范围输入框焦点的事件类
class ClearSelectionFocusEvent {}

class TSelectionRangeItemWidget extends StatefulWidget {
  final TSelectionEntity item;

  final RangeChangedCallback? onRangeChanged;
  final ValueChanged<bool>? onFocusChanged;

  final bool isShouldClearText;

  final TextEditingController minTextEditingController;
  final TextEditingController maxTextEditingController;

  final TSelectionConfig themeData;

  const TSelectionRangeItemWidget({
    Key? key,
    required this.item,
    required this.minTextEditingController,
    required this.maxTextEditingController,
    this.isShouldClearText = false,
    this.onRangeChanged,
    this.onFocusChanged,
    required this.themeData,
  }) : super(key: key);

  @override
  TSelectionRangeItemWidgetState createState() =>
      TSelectionRangeItemWidgetState();
}

class TSelectionRangeItemWidgetState
    extends State<TSelectionRangeItemWidget> {
  final FocusNode _minFocusNode = FocusNode();
  final FocusNode _maxFocusNode = FocusNode();

  @override
  void initState() {
    widget.minTextEditingController.text =
        (widget.item.customMap != null && widget.item.customMap!['min'] != null)
            ? widget.item.customMap!['min']?.toString() ?? ''
            : '';
    widget.maxTextEditingController.text =
        (widget.item.customMap != null && widget.item.customMap!['max'] != null)
            ? widget.item.customMap!['max']?.toString() ?? ''
            : '';

    //输入框焦点
    _minFocusNode.addListener(() {
      if (widget.onFocusChanged != null) {
        widget
            .onFocusChanged!(_minFocusNode.hasFocus || _maxFocusNode.hasFocus);
      }
    });

    _maxFocusNode.addListener(() {
      if (widget.onFocusChanged != null) {
        widget
            .onFocusChanged!(_minFocusNode.hasFocus || _maxFocusNode.hasFocus);
      }
    });

    widget.minTextEditingController.addListener(() {
      String minInput = widget.minTextEditingController.text;

      widget.item.customMap ??= {};
      widget.item.customMap!['min'] = minInput;
      widget.item.isSelected = true;
    });

    widget.maxTextEditingController.addListener(() {
      String maxInput = widget.maxTextEditingController.text;
      widget.item.customMap ??= {};
      widget.item.customMap!['max'] = maxInput;
      widget.item.isSelected = true;
    });

    TEventBus.instance
        .on<ClearSelectionFocusEvent>()
        .listen((ClearSelectionFocusEvent event) {
      _minFocusNode.unfocus();
      _maxFocusNode.unfocus();
    });

    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Padding(
      padding: const EdgeInsets.only(left: 20, right: 20, bottom: 20),
      child: Column(
        children: <Widget>[
          Container(
            margin: const EdgeInsets.only(bottom: 5),
            alignment: Alignment.centerLeft,
            child: Text(
              "${widget.item.title.isNotEmpty ? widget.item.title : '自定义区间'}(${widget.item.extMap['unit']?.toString() ?? ''})",
              textAlign: TextAlign.left,
              style: const TextStyle(color:  Color(0xFF222222), fontSize: 16.0, fontWeight: FontWeight.w600),
            ),
          ),
          Row(
            children: <Widget>[
              getRangeTextField(false),
              const Text(
                '至',
                style: TextStyle(color:  Color(0xFF222222), fontSize: 14.0),
              ),
              getRangeTextField(true),
            ],
          )
        ],
      ),
    );
  }

  Widget getRangeTextField(bool isMax) {
    return Expanded(
      child: TextFormField(
        style: const TextStyle(color:  Color(0xFF222222), fontSize: 14.0),
        inputFormatters: [FilteringTextInputFormatter.digitsOnly],
        keyboardType: const TextInputType.numberWithOptions(),
        onChanged: (input) {
          widget.item.isSelected = true;
        },
        focusNode: isMax ? _maxFocusNode : _minFocusNode,
        controller: isMax
            ? widget.maxTextEditingController
            : widget.minTextEditingController,
        cursorColor: const Color(0xFF3072F6),
        textAlign: TextAlign.center,
        decoration: InputDecoration(
          hintStyle: const TextStyle(color:  Color(0xFFCCCCCC), fontSize: 14.0),
          hintText: (isMax ? '最大值' : '最小值'),
          enabledBorder: const UnderlineInputBorder(
              borderSide: BorderSide(
            width: 1,
            color: Color(0xFFF0F0F0),
          )),
          focusedBorder: const UnderlineInputBorder(
              borderSide: BorderSide(
            width: 1,
            color: Color(0xFFF0F0F0),
          )),
          contentPadding: const EdgeInsets.all(0),
        ),
      ),
    );
  }
}
